#!/usr/bin/env python


import MDAnalysis as mda
import numpy as np


u = mda.Universe("system.data", atom_style="id mol type q x y z")
pos = u.atoms.positions


n_water = 500
n_methanol = 1
n_residues = n_water + n_methanol
n_atoms = n_water * 3 + n_methanol * 6


water_resind = np.repeat(range(n_water), 3)
methanol_resind = [1, 1, 1, 1, 1, 1] + water_resind[-1]
resindices = np.hstack([water_resind, methanol_resind])


un = mda.Universe.empty(
    n_atoms, n_residues=n_residues, atom_resindex=resindices, trajectory=True
)  # necessary for adding coordinates


water_atom_names = ["OW", "HW1", "HW2"]
methanol_atom_names = ["C", "O", "HA", "HB", "HC", "H"]
names = np.hstack([water_atom_names * n_water, methanol_atom_names * n_methanol])


un.add_TopologyAttr("name", names)


resnames = np.hstack([np.repeat("SOL", n_water), np.repeat("MeO", n_methanol)])


un.add_TopologyAttr("resname", resnames)


un.add_TopologyAttr("resid", list(range(1, n_residues + 1)))


un.atoms.positions = pos


un.atoms.write("system.gro")

